/**
 * Copyright 2007 Nathanael Cottin
 */
package sds;

import sds.error.ProcessException;
import sds.error.SdsException;

/**
 * <p>
 * Defines client-oriented distributed objects. These objects are only able to
 * deliver messages (and cannot receive messages)
 * </p>
 * 
 * @see DistributedServerObject
 * @author ncottin
 */
public abstract class DistributedClientObject extends DistributedObject {

	/**
	 * <p>
	 * Creates a client-oriented distributed object able to deliver messages to
	 * server-oriented distributed objects
	 * </p>
	 */
	public DistributedClientObject() {
	}

	/**
	 * <p>
	 * Checks if this distributed object can receive message
	 * </p>
	 * 
	 * @return <tt>false</tt> as this distributed object cannot be used as a
	 * server
	 */
	@Override
	public final boolean runsAsServer() {
		return false;
	}

	/**
	 * <p>
	 * This operation must not be used as it raises a
	 * {@link sds.error.ProcessException}
	 * </p>
	 * 
	 * @param port any value
	 * @param daemon any boolean value
	 * @throws SdsException always raised as this object is not a server
	 */
	@Override
	public final void run(int port, boolean daemon) throws SdsException {
		throw new ProcessException("Not a server");
	}
}
