/**
 * Copyright 2007 Nathanael Cottin
 */
package sds;

import java.io.Serializable;

import sds.data.Message;
import sds.data.Reference;

/**
 * <p>
 * Message envelope: placeholder for a {@link sds.data.Message} sent to a
 * recipient (server-oriented distributed object). This message envelope is to
 * be enclosed within a {@link SecureMessageFormat}
 * </p>
 * 
 * @author ncottin
 */
final class MessageData implements Serializable {

	private Reference	recipient	= null;
	private Message		msg			= null;

	/**
	 * @return the recipient of the message
	 */
	public Reference getRecipient() {
		return recipient;
	}

	/**
	 * <p>
	 * Initializes the recipient of a message
	 * </p>
	 * 
	 * @param recipient the recipient to set. This recipient's reference must be
	 * invokable (i.e. correspond to a server-oriented distributed object) to be
	 * able to deliver the associated message
	 */
	public void setRecipient(Reference recipient) {
		this.recipient = recipient;
	}

	/**
	 * <p>
	 * Gets the message content
	 * </p>
	 * 
	 * @return the message contained by this envelope
	 */
	public Message getMessage() {
		return msg;
	}

	/**
	 * <p>
	 * Initializes the message content to be delivered
	 * </p>
	 * 
	 * @param msg the message to initialize this envelope with
	 */
	public void setMessage(Message msg) {
		this.msg = msg;
	}
}
