/**
 * Copyright 2007 Nathanael Cottin
 */
package sds.more;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;

/**
 * <p>
 * SDS encoder/decoder used to marshall requests and unmarshall responses
 * </p>
 * 
 * @author ncottin
 */
public final class Codec {

	/**
	 * <p>
	 * Creates an encoding of the given object and writes the resulting flow to
	 * the provided output stream
	 * </p>
	 * 
	 * @param obj The object to encode
	 * @param out The destination stream
	 * @throws IOException An argument is <tt>null</tt> or an internal
	 * encoding error occurred
	 * 
	 */
	public static void encode(Serializable obj, OutputStream out)
		throws IOException {
		ObjectOutputStream objOut = new ObjectOutputStream(out);
		objOut.writeObject(obj);
	}

	/**
	 * <p>
	 * Decodes an object from a source stream
	 * </p>
	 * 
	 * @param in The source stream use to recreate the object from
	 * @return A non-<tt>null</tt> object read from the source stream
	 * @throws IOException The source stream is <tt>null</tt> or does not
	 * contain a valid encoding
	 * @throws ClassNotFoundException The object class is locally unknown
	 */
	public static Object decode(InputStream in)
		throws IOException,
			ClassNotFoundException {
		ObjectInputStream objIn = new ObjectInputStream(in);
		return objIn.readObject();
	}
}
