/**
 * Copyright 2007 Nathanael Cottin
 */
package sds.more;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import sds.DistributedObject;

/**
 * @author ncottin
 * 
 */
public final class SimpleClassLoader extends ClassLoader {

	private static final char	DOT				= '.';
	private static final char	SEP				= '/';
	private static final String	CLASS_EXTENSION	= ".class";

	public Class<?> loadClass(String name, byte[] bytecode, boolean resolve)
		throws ClassNotFoundException {
		if ((name == null) || "".equals(name) || (bytecode == null)
			|| (bytecode.length == 0)) {
			return null;
		}

		Class<?> cl = defineClass(name, bytecode, 0, bytecode.length);
		if (cl == null) {
			return null;
		}

		if (resolve) {
			resolveClass(cl);
		}

		return cl;
	}

	public static byte[] getByteCode(Class<? extends DistributedObject> cl)
		throws IOException,
			InstantiationException,
			IllegalAccessException {
		if (cl == null) {
			return null;
		}

		return getByteCode(getLocation(cl), cl.getName());
	}

	private static byte[] getByteCode(URL location, String name)
		throws IOException {
		StringBuffer sb = new StringBuffer();
		sb.append(location.getFile());
		sb.append(name.replace(DOT, SEP));
		sb.append(CLASS_EXTENSION);

		InputStream in = new FileInputStream(sb.toString());
		sb = null;
		byte[] data = new byte[in.available()];
		in.read(data);
		in.close();

		return data;
	}

	public static URL getLocation(Class<?> cl)
		throws InstantiationException,
			IllegalAccessException {
		if (cl == null) {
			return null;
		}

		return cl.getProtectionDomain().getCodeSource().getLocation();
	}
}
