/**
 * Copyright 2007 Nathanael Cottin
 */
package sds.service;

import sds.DistributedServerObject;

/**
 * <p>
 * Defines derived distributed objects as services. A service is never linked
 * with a manager. It is recommended to secure services with digital signature
 * (when constructing)
 * </p>
 * 
 * @author ncottin
 */
abstract class CommonService extends DistributedServerObject {

	protected static final int	CREATE_TAG_REQUEST	= -1;
	protected static final int	CREATE_TAG_RESPONSE	= -2;
	protected static final int	KILL_TAG_REQUEST	= -3;
	protected static final int	KILL_TAG_RESPONSE	= -4;

	/**
	 * <p>
	 * Creates a non-initialized common service with no associated reference.
	 * Every service requires incoming messages to be digitally signed
	 * </p>
	 * 
	 * @param requiresSignature <tt>true</tt> if all incoming non digitally
	 * signed messages must be rejected
	 */
	public CommonService(boolean requiresSignature) {
		super(requiresSignature);
	}
}
